@@ -101,7 +101,7 @@ $TRANSLATIONS = array(
 "can edit" => "pot editar",
 "access control" => "control d'accés",
 "create" => "crea",
-"change" => "canvi",
+"change" => "cambi",
 "delete" => "elimina",
 "Password protected" => "Protegeix amb contrasenya",
 "Error unsetting expiration date" => "Error en eliminar la data de venciment",
