@@ -3,7 +3,7 @@ OC.L10N.register(
     {
     "Documents" : "Dokumentoj",
     "Can't create document" : "Ne povas kreiĝi dokumento",
-    "You don't have permission to rename this document" : "Vi ne permesatas alinomigi ĉi tiun dokumenton",
+    "You don't have permission to rename this document" : "Vi ne havas permeson alinomigi ĉi tiun dokumenton",
     "Directory saved successfully." : "La dosierujo konserviĝis sukcese.",
     "An error occurred while changing directory." : "Eraro okazis dum ŝanĝo de dosierujo.",
     "Saved" : "Konservita",
@@ -71,26 +71,16 @@ OC.L10N.register(
     "Error while changing permissions" : "Eraro dum ŝanĝo de permesoj",
     "Shared with you and the group {group} by {owner}" : "Kunhavigita kun vi kaj la grupo {group} de {owner}",
     "Shared with you by {owner}" : "Kunhavigita kun vi de {owner}",
-    "Share with users or groups …" : "Kunhavigi kun uzantoj aŭ grupoj.",
-    "Share with users, groups or remote users …" : "Kunhavigi kun uzantoj, grupoj aŭ foraj uzantoj...",
     "Share" : "Kunhavigi",
-    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Kunhaviki kun homoj en aliaj ownCloud-oj uzante la sintakson uzantonomo@example.com/owncloud",
     "Share link" : "Kunhavigi ligilon",
-    "The public link will expire no later than {days} days after it is created" : "La publika ligilo senvalidiĝos ne pli malfrue ol {days} tagojn post ĝi kreiĝos",
-    "Link" : "Ligilo",
     "Password protect" : "Protekti per pasvorto",
     "Password" : "Pasvorto",
-    "Choose a password for the public link" : "Elektu pasvorton por la publika ligilo",
-    "Allow editing" : "Permesi redakton",
     "Email link to person" : "Retpoŝti la ligilon al ulo",
     "Send" : "Sendi",
     "Set expiration date" : "Agordi limdaton",
     "Expiration" : "Eksvalidiĝo",
     "Expiration date" : "Limdato",
-    "An error occured. Please try again" : "Eraro okazis, Bonvolu provi ree.",
-    "Adding user..." : "Aldonante uzanton...",
     "group" : "grupo",
-    "remote" : "fora",
     "Resharing is not allowed" : "Rekunhavigo ne permesatas",
     "Shared in {item} with {user}" : "Kunhavigita en {item} kun {user}",
     "Unshare" : "Malkunhavigi",
@@ -99,7 +89,6 @@ OC.L10N.register(
     "can edit" : "povas redakti",
     "access control" : "alirkontrolo",
     "create" : "krei",
-    "change" : "ŝanĝi",
     "delete" : "forigi",
     "Password protected" : "Protektita per pasvorto",
     "Error unsetting expiration date" : "Eraro dum malagordado de limdato",
@@ -109,13 +98,11 @@ OC.L10N.register(
     "Warning" : "Averto",
     "Edit" : "Redakti",
     "guest" : "gasto",
-    "MS Word support (requires openOffice/libreOffice)" : "Kongruo kun MS Word (postulas OpenOffice/LibreOffice-n)",
+    "MS Word support (requires openOffice/libreOffice)" : "Kongruo kun MS Word (postuliĝas openOffice/libreOffice)",
     "Local" : "Loka",
     "External" : "Malena",
     "Disabled" : "Malkapabligita",
-    "No MS Word support" : "Neniu kongruo kun MS Word",
     "Server URL" : "Servila URL",
-    "Apply and test" : "Apliki kaj provi",
     "New document" : "Nova dokumento",
     "Upload (max. %s)" : "Alŝuti (maks. %s)",
     "Upload" : "Alŝuti",
