@@ -6,7 +6,6 @@ $TRANSLATIONS = array(
 "Directory saved successfully." => "תיקייה נשמרה בהצלחה",
 "An error occurred while changing directory." => "שגיאה אירעה בזמן שינוי התיקייה",
 "Saved" => "נשמר",
-"Format filter server is down or misconfigured" => "שרת החלפת פורמט אינו מקוון או לא מקונפג",
 "Conversion failed. Check log for details." => "המרה נכשלה. יש לבדוק לוג פעילות לפרטים.",
 "Saving..." => "שמירה…",
 "Failed to load documents." => "טעינת מסמך נכשלה",
@@ -73,35 +72,22 @@ $TRANSLATIONS = array(
 "Error while changing permissions" => "שגיאה במהלך שינוי ההגדרות",
 "Shared with you and the group {group} by {owner}" => "שותף אתך ועם הקבוצה {group} שבבעלות {owner}",
 "Shared with you by {owner}" => "שותף אתך על ידי {owner}",
-"Share with users or groups …" => "שיתוף עם משתמשים או קבוצות...",
-"Share with users, groups or remote users …" => "שיתוף עם משתמשים, קבוצות או משתמשים חצוניים...",
 "Share" => "שיתוף",
-"Share with people on other ownClouds using the syntax username@example.com/owncloud" => "ניתן לשתף עם אנשים אחרים המשתמשים ב- ownClouds בעזרת הפורמט הבא username@example.com/owncloud",
 "Share link" => "קישור לשיתוף",
-"The public link will expire no later than {days} days after it is created" => "הקישור הציבורי יפוג עד {days} ימים לאחר שנוצר",
-"Link" => "קישור",
 "Password protect" => "הגנה בססמה",
 "Password" => "סיסמא",
-"Choose a password for the public link" => "בחירת סיסמא לקישור ציבורי",
-"Allow editing" => "אישור עריכה",
 "Email link to person" => "שליחת קישור בדוא״ל למשתמש",
 "Send" => "שליחה",
 "Set expiration date" => "הגדרת תאריך תפוגה",
-"Expiration" => "תפוגה",
 "Expiration date" => "תאריך התפוגה",
-"An error occured. Please try again" => "אירעה שגיאה. יש לנסות בבקשה שוב",
-"Adding user..." => "הוספת משתמש...",
 "group" => "קבוצה",
-"remote" => "נשלט מרחוק",
 "Resharing is not allowed" => "אסור לעשות שיתוף מחדש",
 "Shared in {item} with {user}" => "שותף תחת {item} עם {user}",
 "Unshare" => "הסר שיתוף",
-"notify by email" => "קבלת הודעה בדואר אלקטרוני",
 "can share" => "ניתן לשתף",
 "can edit" => "ניתן לערוך",
 "access control" => "בקרת גישה",
 "create" => "יצירה",
-"change" => "שינוי",
 "delete" => "מחיקה",
 "Password protected" => "מוגן בססמה",
 "Error unsetting expiration date" => "אירעה שגיאה בביטול תאריך התפוגה",
@@ -113,22 +99,13 @@ $TRANSLATIONS = array(
 "guest" => "אורח",
 "MS Word support (requires openOffice/libreOffice)" => "MS Word(דורש openOffice/libreOfficeתמיכת )",
 "Local" => "מקומי",
-"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "openOffice/libreOffice מותקן על השרת. קישור ל- binary נקבע על בסיס preview_libreoffice_path בקובץ config.php",
 "External" => "חיצוני",
-"openOffice/libreOffice is installed on external server running a format filter server" => "openOffice/libreOffice מותקן על שרת חיצוני ומפעיל שרת החלפת פורמט",
-"Disabled" => "מנוטרל",
-"No MS Word support" => "אין תמיכה לוורד",
-"scheme://domain.tld[:port]" => "scheme://domain.tld[:port]",
 "Server URL" => "נתיב השרת",
 "Apply and test" => "ביצוע ובדיקה",
 "New document" => "מסמך חדש",
 "Upload (max. %s)" => "העלאה (מקסימום %s)",
 "Upload" => "העלאה",
 "Save new documents to" => "שמירת מסמך חדש אל",
-"Wrong password. Please retry." => "סיסמא שגויה. נא לנסות שוב",
-"Guest %s" => "אורח %s",
-"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "קישור זה אינו תקף או לא קיים. יש ליצור קשר עם האדם, ששיתף את הקישור אתך, לפרטים.",
-"Advanced feature-set" => "מערכת אפשרויות מתקדמות",
-"(Unstable)" => "(לא יציב)"
+"Wrong password. Please retry." => "סיסמא שגויה. נא לנסות שוב"
 );
 $PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
