@@ -3,7 +3,6 @@ $TRANSLATIONS = array(
 "Documents" => "ドキュメント",
 "Can't create document" => "文書を生成することができません",
 "You don't have permission to rename this document" => "ドキュメント名を変更する権限がありません",
-"File does not exist" => "ファイルが存在しません",
 "Directory saved successfully." => "ディレクトリの保存に成功しました。",
 "An error occurred while changing directory." => "ディレクトリの変更中にエラーが発生しました。",
 "Saved" => "保存されました",
@@ -84,7 +83,7 @@ $TRANSLATIONS = array(
 "Password protect" => "パスワード保護を有効化",
 "Password" => "パスワード",
 "Choose a password for the public link" => "URLによる共有のパスワードを入力",
-"Allow editing" => "編集を許可",
+"Allow editing" => "編集許可",
 "Email link to person" => "メールリンク",
 "Send" => "送信",
 "Set expiration date" => "有効期限を設定",
@@ -126,7 +125,7 @@ $TRANSLATIONS = array(
 "Upload (max. %s)" => "アップロード ( 最大 %s )",
 "Upload" => "アップロード",
 "Save new documents to" => "新規ドキュメントの保存先:",
-"Wrong password. Please retry." => "パスワードが間違っています。もう一度入力してください。",
+"Wrong password. Please retry." => "間違ったパスワード。もう一度入力してください。",
 "Guest %s" => "ゲスト %s",
 "This link has been expired or is never existed. Please contact the person who shared it with you for details." => "このリンクは期限が切れているか、すでに存在しません。詳細は、それを共有した方に連絡していください。",
 "Advanced feature-set" => "高度な機能セット",
