@@ -4,7 +4,6 @@ OC.L10N.register(
     "Documents" : "Documentos",
     "Can't create document" : "Impedido de criar documentos",
     "You don't have permission to rename this document" : "Você não tem permissão para renomear este documento",
-    "File does not exist" : "O arquivo não existe",
     "Directory saved successfully." : "Diretório salvo com sucesso.",
     "An error occurred while changing directory." : "Ocorreu um erro ao mudar de diretório.",
     "Saved" : "Salvo",
@@ -40,7 +39,7 @@ OC.L10N.register(
     "Delete" : "Eliminar",
     "Family" : "Família",
     "Font" : "Fonte",
-    "Font Effects" : "Efeitos da Fonte",
+    "Font Effects" : "Fonte Efeitos",
     "Format" : "Formato",
     "Increase Indent" : "Aumentar recuo",
     "Insert Image" : "Inserir Imagem",
@@ -68,7 +67,7 @@ OC.L10N.register(
     "Underline" : "Sublinhado",
     "Undo" : "Desfazer",
     "Unknown Author" : "Autor Desconhecido",
-    "Shared" : "Compartilhado",
+    "Shared" : "Compartilhados",
     "Error" : "Erro",
     "Error while sharing" : "Erro ao compartilhar",
     "Error while unsharing" : "Erro ao descompartilhar",
