@@ -3,7 +3,6 @@ $TRANSLATIONS = array(
 "Documents" => "Dokumenti",
 "Can't create document" => "Dokumenta ni mogoče ustvariti",
 "You don't have permission to rename this document" => "Ni ustreznih dovoljenj za preimenovanje tega dokumenta ...",
-"File does not exist" => "Datoteka ne obstaja",
 "Directory saved successfully." => "Mapa je uspešno shranjena.",
 "An error occurred while changing directory." => "Med spreminjanjem mape je prišlo do napake.",
 "Saved" => "Shranjeno",
@@ -74,10 +73,7 @@ $TRANSLATIONS = array(
 "Error while changing permissions" => "Napaka med spreminjanjem dovoljenj",
 "Shared with you and the group {group} by {owner}" => "V souporabi z vami in skupino {group}. Lastnik je {owner}.",
 "Shared with you by {owner}" => "V souporabi z vami. Lastnik je {owner}.",
-"Share with users or groups …" => "Souporaba z uporabniki ali skupinami ...",
-"Share with users, groups or remote users …" => "Uporabniki, skupine ali zunanji uporabniki ...",
 "Share" => "Souporaba",
-"Share with people on other ownClouds using the syntax username@example.com/owncloud" => "Soupraba z ljudmi v drugih ownCloud oblakih v formatu uporabnik@domena.si/owncloud",
 "Share link" => "Povezava za souporabo",
 "The public link will expire no later than {days} days after it is created" => "Javna povezava bo potekla {days} dni po ustvarjanju.",
 "Link" => "Povezava",
@@ -90,7 +86,6 @@ $TRANSLATIONS = array(
 "Set expiration date" => "Nastavi datum preteka",
 "Expiration" => "Datum preteka",
 "Expiration date" => "Datum preteka",
-"An error occured. Please try again" => "Prišlo je do napake. Poskusite znova.",
 "Adding user..." => "Dodajanje uporabnika ...",
 "group" => "skupina",
 "remote" => "oddaljeno",
@@ -102,7 +97,7 @@ $TRANSLATIONS = array(
 "can edit" => "lahko ureja",
 "access control" => "nadzor dostopa",
 "create" => "ustvari",
-"change" => "spremeni",
+"change" => "sprememba",
 "delete" => "izbriši",
 "Password protected" => "Zaščiteno z geslom",
 "Error unsetting expiration date" => "Napaka brisanja datuma preteka",
