@@ -4,7 +4,6 @@ OC.L10N.register(
     "Documents" : "Dokument",
     "Can't create document" : "Kan inte skapa dokument",
     "You don't have permission to rename this document" : "Du har inte behörighet att döpa om detta dokument",
-    "File does not exist" : "Filen finns inte",
     "Directory saved successfully." : "Katalog sparades.",
     "An error occurred while changing directory." : "Ett fel uppstod vid byte av katalog",
     "Saved" : "Sparad",
@@ -75,10 +74,7 @@ OC.L10N.register(
     "Error while changing permissions" : "Fel vid ändring av rättigheter",
     "Shared with you and the group {group} by {owner}" : "Delad med dig och gruppen {group} av {owner}",
     "Shared with you by {owner}" : "Delad med dig av {owner}",
-    "Share with users or groups …" : "Dela med användare eller grupper ...",
-    "Share with users, groups or remote users …" : "Dela med användare, grupper eller fjärranvändare ...",
     "Share" : "Dela",
-    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Dela med folk på andra ownClouds med följande syntax username@example.com/owncloud",
     "Share link" : "Dela länk",
     "The public link will expire no later than {days} days after it is created" : "Den publika länken kommer sluta gälla inte senare än {days} dagar efter att den skapades",
     "Link" : "Länk",
@@ -91,7 +87,6 @@ OC.L10N.register(
     "Set expiration date" : "Sätt utgångsdatum",
     "Expiration" : "Upphör",
     "Expiration date" : "Utgångsdatum",
-    "An error occured. Please try again" : "Ett fel uppstod. Var god försök igen",
     "Adding user..." : "Lägger till användare...",
     "group" : "Grupp",
     "remote" : "fjärr",
