@@ -51,15 +51,17 @@ class DocumentControllerTest extends \PHPUnit_Framework_TestCase {
 		\OC_Util::setupFS();
 	}
 	
-
 	public function testRename(){
-
+		$result = array(
+			'status' => 'error',
+			'message' => (string) $this->l10n->t('You don\'t have permission to rename this document')
+		);
 		$this->request->post = array(
-			'fileId' => 1500,
+			'fileId' => 500,
 			'name' => 'newname.ext'
 		);
-		$response = $this->controller->rename(1500);
-		$this->assertEquals('error', $response['status']);
+		$response = $this->controller->rename(500);
+		$this->assertEquals($result, $response);
 	}
 	
 	public function testCreate(){
